/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Ext, NX*/

/**
 * Helpers to interact with Message controller.
 *
 * @since 3.0
 */
Ext.define('NX.Messages', {
  singleton: true,

  /**
   * Add a new custom message.
   *
   * @public
   * @param {Object} message
   */
  add: function (message) {
    NX.getApplication().getMessageController().addMessage(message);
  },

  //
  // High-level helpers
  //

  /**
   * Add a notice message.
   *
   * @public
   * @param {string} message
   */
  notice: function (message) {
    this.add({type: 'default', text: message});
  },

  /**
   * Add an info message.
   *
   * @public
   * @param {string} message
   */
  info: function (message) {
    this.add({type: 'primary', text: message});
  },

  /**
   * Add an error message.
   *
   * @public
   * @param {string} message
   */
  error: function (message) {
    this.add({type: 'danger', text: message});
  },

  /**
   * Add a warning message.
   *
   * @public
   * @param {string} message
   */
  warning: function (message) {
    this.add({type: 'warning', text: message});
  },

  /**
   * Add a success message.
   *
   * @public
   * @param {string} message
   */
  success: function (message) {
    this.add({type: 'success', text: message});
  }
});