/*
 * Copyright (c) 2008-present Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Ext, NX*/

/**
 * CLM settings form.
 *
 * @since 3.0
 */
Ext.define('NX.proui.view.clm.ClmSettings', {
  extend: 'NX.view.SettingsPanel',
  alias: 'widget.nx-proui-clm-settings',
  requires: [
    'NX.Conditions',
    'NX.I18n'
  ],

  /**
   * @override
   */
  initComponent: function () {
    var me = this;

    me.settingsForm = {
      xtype: 'nx-settingsform',
      settingsFormSuccessMessage: 'IQ Server Settings $action',
      api: {
        load: 'NX.direct.clm_CLM.read',
        submit: 'NX.direct.clm_CLM.update'
      },
      editableCondition: NX.Conditions.isPermitted('nexus:settings:update'),
      editableMarker: NX.I18n.get('Clm_ClmSettings_Permission_Error'),
      items: [
        {
          xtype: 'label',
          html: NX.I18n.get('ClmSettings_Html')
        },
        {
          xtype: 'checkbox',
          name: 'enabled',
          fieldLabel: NX.I18n.get('ClmSettings_Enable_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_Enable_HelpText')
        },
        {
          xtype: 'nx-url',
          name: 'url',
          fieldLabel: NX.I18n.get('ClmSettings_URL_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_URL_HelpText'),
          emptyText: NX.I18n.get('ClmSettings_URL_EmptyText')
        },
        {
          name: 'username',
          fieldLabel: NX.I18n.get('ClmSettings_Username_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_Username_HelpText'),
          emptyText: NX.I18n.get('ClmSettings_Username_EmptyText')
        },
        {
          xtype: 'nx-password',
          name: 'password',
          fieldLabel: NX.I18n.get('ClmSettings_Password_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_Password_HelpText'),
          emptyText: NX.I18n.get('ClmSettings_Password_EmptyText')
        },
        {
          xtype: 'numberfield',
          name: 'timeout',
          fieldLabel: NX.I18n.get('ClmSettings_ConnectionTimeout_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_ConnectionTimeout_HelpText'),
          emptyText: NX.I18n.get('ClmSettings_ConnectionTimeout_EmptyText'),
          allowBlank: true,
          allowDecimals: false,
          allowExponential: false,
          minValue: 1,
          maxValue: 3600
        },
        {
          xtype: 'textareafield',
          name: 'properties',
          fieldLabel: NX.I18n.get('ClmSettings_Properties_FieldLabel'),
          helpText: NX.I18n.get('ClmSettings_Properties_HelpText'),
          emptyText: NX.I18n.get('ClmSettings_Properties_EmptyText'),
          allowBlank: true
        }
      ]
    };

    me.callParent();

    me.down('nx-settingsform').getDockedItems('toolbar[dock="bottom"]')[0].add({
      xtype: 'button', text: NX.I18n.get('ClmSettings_Properties_Verify_Button'), formBind: true, action: 'verify'
    });
  }

});
